@@ -294,6 +294,7 @@ pub struct EdgeCut {
 pub enum EdgeCutSubType {
     Fillet,
     Chamfer,
+    Custom,
 }
 
 impl From<kcmc::shared::CutType> for EdgeCutSubType {
@@ -305,6 +306,16 @@ impl From<kcmc::shared::CutType> for EdgeCutSubType {
     }
 }
 
+impl From<kcmc::shared::CutTypeV2> for EdgeCutSubType {
+    fn from(cut_type: kcmc::shared::CutTypeV2) -> Self {
+        match cut_type {
+            kcmc::shared::CutTypeV2::Fillet { .. } => EdgeCutSubType::Fillet,
+            kcmc::shared::CutTypeV2::Chamfer { .. } => EdgeCutSubType::Chamfer,
+            kcmc::shared::CutTypeV2::Custom { .. } => EdgeCutSubType::Custom,
+        }
+    }
+}
+
 #[derive(Debug, Clone, Serialize, PartialEq, ts_rs::TS)]
 #[ts(export_to = "Artifact.ts")]
 #[serde(rename_all = "camelCase")]
@@ -1301,6 +1312,31 @@ fn artifacts_to_update(
             }
             return Ok(return_arr);
         }
+        ModelingCmd::Solid3dCutEdges(cmd) => {
+            let mut return_arr = Vec::new();
+            let edge_id = if let Some(edge_id) = cmd.edge_ids.first() {
+                edge_id.into()
+            } else {
+                internal_error!(range, "Solid3dCutEdges command has no edge ID: id={id:?}, cmd={cmd:?}");
+            };
+            return_arr.push(Artifact::EdgeCut(EdgeCut {
+                id,
+                sub_type: cmd.cut_type.into(),
+                consumed_edge_id: edge_id,
+                edge_ids: Vec::new(),
+                surface_id: None,
+                code_ref,
+            }));
+            let consumed_edge = artifacts.get(&edge_id);
+            if let Some(Artifact::Segment(consumed_edge)) = consumed_edge {
+                let mut new_segment = consumed_edge.clone();
+                new_segment.edge_cut_id = Some(id);
+                return_arr.push(Artifact::Segment(new_segment));
+            } else {
+                // TODO: Handle other types like SweepEdge.
+            }
+            return Ok(return_arr);
+        }
         ModelingCmd::EntityMakeHelixFromParams(_) => {
             let return_arr = vec![Artifact::Helix(Helix {
                 id,
