@@ -9,8 +9,8 @@ use crate::{
     CompilationError, KclError, ModuleId, SourceRange,
     errors::KclErrorDetails,
     execution::{
-        EnvironmentRef, ExecState, Face, Geometry, GeometryWithImportedGeometry, Helix, ImportedGeometry, Metadata,
-        Plane, Sketch, Solid, TagIdentifier,
+        EnvironmentRef, ExecState, Face, GdtAnnotation, Geometry, GeometryWithImportedGeometry, Helix,
+        ImportedGeometry, Metadata, Plane, Sketch, SketchVar, SketchVarId, Solid, TagIdentifier,
         annotations::{self, FnAttrs, SETTINGS, SETTINGS_UNIT_LENGTH},
         types::{NumericType, PrimitiveType, RuntimeType},
     },
@@ -49,6 +49,9 @@ pub enum KclValue {
         #[serde(skip)]
         meta: Vec<Metadata>,
     },
+    SketchVar {
+        value: Box<SketchVar>,
+    },
     Tuple {
         value: Vec<KclValue>,
         #[serde(skip)]
@@ -69,6 +72,9 @@ pub enum KclValue {
     },
     TagIdentifier(Box<TagIdentifier>),
     TagDeclarator(crate::parsing::ast::types::BoxNode<TagDeclarator>),
+    GdtAnnotation {
+        value: Box<GdtAnnotation>,
+    },
     Plane {
         value: Box<Plane>,
     },
@@ -132,11 +138,17 @@ pub struct FunctionSource {
     pub ast: crate::parsing::ast::types::BoxNode<FunctionExpression>,
 }
 
+pub struct KclFunctionSourceParams {
+    pub is_std: bool,
+    pub experimental: bool,
+    pub include_in_feature_tree: bool,
+}
+
 impl FunctionSource {
     pub fn rust(
         func: crate::std::StdFn,
         ast: Box<Node<FunctionExpression>>,
-        props: StdFnProps,
+        _props: StdFnProps,
         attrs: FnAttrs,
     ) -> Self {
         let (input_arg, named_args) = Self::args_from_ast(&ast);
@@ -147,22 +159,27 @@ impl FunctionSource {
             return_type: ast.return_type.clone(),
             deprecated: attrs.deprecated,
             experimental: attrs.experimental,
-            include_in_feature_tree: props.include_in_feature_tree,
+            include_in_feature_tree: attrs.include_in_feature_tree,
             is_std: true,
             body: FunctionBody::Rust(func),
             ast,
         }
     }
 
-    pub fn kcl(ast: Box<Node<FunctionExpression>>, memory: EnvironmentRef, is_std: bool) -> Self {
+    pub fn kcl(ast: Box<Node<FunctionExpression>>, memory: EnvironmentRef, params: KclFunctionSourceParams) -> Self {
+        let KclFunctionSourceParams {
+            is_std,
+            experimental,
+            include_in_feature_tree,
+        } = params;
         let (input_arg, named_args) = Self::args_from_ast(&ast);
         FunctionSource {
             input_arg,
             named_args,
             return_type: ast.return_type.clone(),
             deprecated: false,
-            experimental: false,
-            include_in_feature_tree: true,
+            experimental,
+            include_in_feature_tree,
             is_std,
             body: FunctionBody::Kcl(memory),
             ast,
@@ -212,6 +229,23 @@ pub enum TypeDef {
     Alias(RuntimeType),
 }
 
+impl From<Vec<GdtAnnotation>> for KclValue {
+    fn from(mut values: Vec<GdtAnnotation>) -> Self {
+        if values.len() == 1 {
+            let value = values.pop().expect("Just checked len == 1");
+            KclValue::GdtAnnotation { value: Box::new(value) }
+        } else {
+            KclValue::HomArray {
+                value: values
+                    .into_iter()
+                    .map(|s| KclValue::GdtAnnotation { value: Box::new(s) })
+                    .collect(),
+                ty: RuntimeType::Primitive(PrimitiveType::GdtAnnotation),
+            }
+        }
+    }
+}
+
 impl From<Vec<Sketch>> for KclValue {
     fn from(mut eg: Vec<Sketch>) -> Self {
         if eg.len() == 1 {
@@ -250,6 +284,7 @@ impl From<KclValue> for Vec<SourceRange> {
         match item {
             KclValue::TagDeclarator(t) => vec![SourceRange::new(t.start, t.end, t.module_id)],
             KclValue::TagIdentifier(t) => to_vec_sr(&t.meta),
+            KclValue::GdtAnnotation { value } => to_vec_sr(&value.meta),
             KclValue::Solid { value } => to_vec_sr(&value.meta),
             KclValue::Sketch { value } => to_vec_sr(&value.meta),
             KclValue::Helix { value } => to_vec_sr(&value.meta),
@@ -260,6 +295,7 @@ impl From<KclValue> for Vec<SourceRange> {
             KclValue::Bool { meta, .. } => to_vec_sr(&meta),
             KclValue::Number { meta, .. } => to_vec_sr(&meta),
             KclValue::String { meta, .. } => to_vec_sr(&meta),
+            KclValue::SketchVar { value, .. } => to_vec_sr(&value.meta),
             KclValue::Tuple { meta, .. } => to_vec_sr(&meta),
             KclValue::HomArray { value, .. } => value.iter().flat_map(Into::<Vec<SourceRange>>::into).collect(),
             KclValue::Object { meta, .. } => to_vec_sr(&meta),
@@ -280,6 +316,7 @@ impl From<&KclValue> for Vec<SourceRange> {
         match item {
             KclValue::TagDeclarator(t) => vec![SourceRange::new(t.start, t.end, t.module_id)],
             KclValue::TagIdentifier(t) => to_vec_sr(&t.meta),
+            KclValue::GdtAnnotation { value } => to_vec_sr(&value.meta),
             KclValue::Solid { value } => to_vec_sr(&value.meta),
             KclValue::Sketch { value } => to_vec_sr(&value.meta),
             KclValue::Helix { value } => to_vec_sr(&value.meta),
@@ -290,6 +327,7 @@ impl From<&KclValue> for Vec<SourceRange> {
             KclValue::Bool { meta, .. } => to_vec_sr(meta),
             KclValue::Number { meta, .. } => to_vec_sr(meta),
             KclValue::String { meta, .. } => to_vec_sr(meta),
+            KclValue::SketchVar { value, .. } => to_vec_sr(&value.meta),
             KclValue::Uuid { meta, .. } => to_vec_sr(meta),
             KclValue::Tuple { meta, .. } => to_vec_sr(meta),
             KclValue::HomArray { value, .. } => value.iter().flat_map(Into::<Vec<SourceRange>>::into).collect(),
@@ -315,11 +353,13 @@ impl KclValue {
             KclValue::Bool { value: _, meta } => meta.clone(),
             KclValue::Number { meta, .. } => meta.clone(),
             KclValue::String { value: _, meta } => meta.clone(),
+            KclValue::SketchVar { value, .. } => value.meta.clone(),
             KclValue::Tuple { value: _, meta } => meta.clone(),
             KclValue::HomArray { value, .. } => value.iter().flat_map(|v| v.metadata()).collect(),
             KclValue::Object { meta, .. } => meta.clone(),
             KclValue::TagIdentifier(x) => x.meta.clone(),
             KclValue::TagDeclarator(x) => vec![x.metadata()],
+            KclValue::GdtAnnotation { value } => value.meta.clone(),
             KclValue::Plane { value } => value.meta.clone(),
             KclValue::Face { value } => value.meta.clone(),
             KclValue::Sketch { value } => value.meta.clone(),
@@ -348,11 +388,13 @@ impl KclValue {
         match self {
             KclValue::Uuid { .. } => false,
             KclValue::Bool { .. } | KclValue::Number { .. } | KclValue::String { .. } => true,
-            KclValue::Tuple { .. }
+            KclValue::SketchVar { .. }
+            | KclValue::Tuple { .. }
             | KclValue::HomArray { .. }
             | KclValue::Object { .. }
             | KclValue::TagIdentifier(_)
             | KclValue::TagDeclarator(_)
+            | KclValue::GdtAnnotation { .. }
             | KclValue::Plane { .. }
             | KclValue::Face { .. }
             | KclValue::Sketch { .. }
@@ -373,6 +415,7 @@ impl KclValue {
             KclValue::Uuid { .. } => "a unique ID (uuid)".to_owned(),
             KclValue::TagDeclarator(_) => "a tag declarator".to_owned(),
             KclValue::TagIdentifier(_) => "a tag identifier".to_owned(),
+            KclValue::GdtAnnotation { .. } => "an annotation".to_owned(),
             KclValue::Solid { .. } => "a solid".to_owned(),
             KclValue::Sketch { .. } => "a sketch".to_owned(),
             KclValue::Helix { .. } => "a helix".to_owned(),
@@ -391,6 +434,7 @@ impl KclValue {
             } => format!("a number ({units})"),
             KclValue::Number { .. } => "a number".to_owned(),
             KclValue::String { .. } => "a string".to_owned(),
+            KclValue::SketchVar { .. } => "a sketch variable".to_owned(),
             KclValue::Object { .. } => "an object".to_owned(),
             KclValue::Module { .. } => "a module".to_owned(),
             KclValue::Type { .. } => "a type".to_owned(),
@@ -422,13 +466,20 @@ impl KclValue {
         }
     }
 
-    pub(crate) fn from_numeric_literal(literal: &Node<NumericLiteral>, exec_state: &mut ExecState) -> Self {
+    pub(crate) fn from_sketch_var_literal(
+        literal: &Node<NumericLiteral>,
+        id: SketchVarId,
+        exec_state: &ExecState,
+    ) -> Self {
         let meta = vec![literal.metadata()];
         let ty = NumericType::from_parsed(literal.suffix, &exec_state.mod_local.settings);
-        KclValue::Number {
-            value: literal.value,
-            meta,
-            ty,
+        KclValue::SketchVar {
+            value: Box::new(SketchVar {
+                id,
+                initial_value: literal.value,
+                meta,
+                ty,
+            }),
         }
     }
 
@@ -674,6 +725,13 @@ impl KclValue {
         }
     }
 
+    pub fn as_sketch_var(&self) -> Option<&SketchVar> {
+        match self {
+            KclValue::SketchVar { value, .. } => Some(value),
+            _ => None,
+        }
+    }
+
     pub fn as_mut_tag(&mut self) -> Option<&mut TagIdentifier> {
         match self {
             KclValue::TagIdentifier(value) => Some(value),
@@ -753,8 +811,11 @@ impl KclValue {
     pub fn value_str(&self) -> Option<String> {
         match self {
             KclValue::Bool { value, .. } => Some(format!("{value}")),
+            // TODO: Show units.
             KclValue::Number { value, .. } => Some(format!("{value}")),
             KclValue::String { value, .. } => Some(format!("'{value}'")),
+            // TODO: Show units.
+            KclValue::SketchVar { value, .. } => Some(format!("var {}", value.initial_value)),
             KclValue::Uuid { value, .. } => Some(format!("{value}")),
             KclValue::TagDeclarator(tag) => Some(format!("${}", tag.name)),
             KclValue::TagIdentifier(tag) => Some(format!("${}", tag.value)),
@@ -763,6 +824,7 @@ impl KclValue {
             KclValue::HomArray { .. } => Some("[...]".to_owned()),
             KclValue::Object { .. } => Some("{ ... }".to_owned()),
             KclValue::Module { .. }
+            | KclValue::GdtAnnotation { .. }
             | KclValue::Solid { .. }
             | KclValue::Sketch { .. }
             | KclValue::Helix { .. }
